@@ -1,7 +1,7 @@
 package App::fatten;
 
 our $DATE = '2015-04-15'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -67,6 +67,7 @@ sub _trace {
         method => $self->{trace_method},
         script => $self->{input_file},
         args => $self->{args},
+        (multiple_runs => $self->{multiple_runs}) x !!$self->{multiple_runs},
         use => $self->{use},
         recurse_exclude_core => $self->{exclude_core} ? 1:0,
         detail => 1,
@@ -559,8 +560,8 @@ module. The distribution of that module and the recursive dependencies for _that
 distribution_ will be retrieved recursively using `lcpan`. All these will be
 excluded from being fatpacked.
 
-This option can be used to express dependency to an XS module, since a script
-cannot fatpack XS modules.
+This option can be used to express dependency to an XS module, since XS modules
+cannot be fatpacked.
 
 This option requires that `lcpan` is installed and a fairly recent lcpan index
 is available.
@@ -591,9 +592,9 @@ _
             'summary.alt.plurality.singular' => 'Script argument',
             description => <<'_',
 
-Will be used when running your script, e.g. when `trace_method` is `require`.
-For example, if your script requires three arguments: `--foo`, `2`, `"bar baz"`
-then you can either use:
+Will be used when running your script, e.g. when `trace_method` is `fatpacker`
+or `require`. For example, if your script requires three arguments: `--foo`,
+`2`, `"bar baz"` then you can either use:
 
     % fatten script output --args --foo --args 2 --args "bar baz"
 
@@ -604,6 +605,10 @@ or:
 _
             schema => ['array*' => of => 'str*'],
         },
+        multiple_runs => {
+            summary => 'Pass to tracepm',
+            schema => ['array*' => of => ['hash*']],
+        },
 
         shebang => {
             summary => 'Set shebang line/path',
@@ -883,7 +888,7 @@ App::fatten - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.35 of App::fatten (from Perl distribution App-fatten), released on 2015-04-15.
+This document describes version 0.36 of App::fatten (from Perl distribution App-fatten), released on 2015-04-15.
 
 =head1 SYNOPSIS
 
@@ -915,8 +920,8 @@ module. The distribution of that module and the recursive dependencies for I<tha
 distribution> will be retrieved recursively using C<lcpan>. All these will be
 excluded from being fatpacked.
 
-This option can be used to express dependency to an XS module, since a script
-cannot fatpack XS modules.
+This option can be used to express dependency to an XS module, since XS modules
+cannot be fatpacked.
 
 This option requires that C<lcpan> is installed and a fairly recent lcpan index
 is available.
@@ -927,9 +932,9 @@ is available.
 
 Script arguments.
 
-Will be used when running your script, e.g. when C<trace_method> is C<require>.
-For example, if your script requires three arguments: C<--foo>, C<2>, C<"bar baz">
-then you can either use:
+Will be used when running your script, e.g. when C<trace_method> is C<fatpacker>
+or C<require>. For example, if your script requires three arguments: C<--foo>,
+C<2>, C<"bar baz"> then you can either use:
 
  % fatten script output --args --foo --args 2 --args "bar baz"
 
@@ -999,6 +1004,10 @@ Path to input file (script to be fatpacked).
 C<-> (or if unspecified) means to take from standard input (internally, a
 temporary file will be created to handle this).
 
+=item * B<multiple_runs> => I<array[hash]>
+
+Pass to tracepm.
+
 =item * B<output_file> => I<str>
 
 Path to output file.
